@@ -14,11 +14,11 @@ from __future__ import unicode_literals
 import codecs
 import copy
 import getpass
+import json
 import logging
 import multiprocessing
 import os
 import platform
-import stat
 import sys
 import textwrap
 import traceback
@@ -572,11 +572,20 @@ def load_envdefs(attributes, settings):
     """
     for name, value in six.iteritems(os.environ):
         if name.startswith("YAMLCONF_"):
+            attrname = name.replace("YAMLCONF_", "")
+            if attributes.get(attrname + ":jsonenv"):
+                try:
+                    value = json.loads(value)
+                except json.decoder.JSONDecodeError as exc:
+                    logger.error(
+                        'YAMLCONF: JSON decode of "%s" failed for "%s": %s',
+                        value, attrname, str(exc)
+                    )
             set_attr_value(
                 attributes,
                 settings,
                 "**ENVIRONMENT**",
-                name.replace("YAMLCONF_", ""),
+                attrname,
                 value
             )
 
